Struct cbindgen::ParseExpandConfig
source · [−]pub struct ParseExpandConfig {
pub crates: Vec<String>,
pub all_features: bool,
pub default_features: bool,
pub features: Option<Vec<String>>,
pub profile: Profile,
}Expand description
Settings to apply when running rustc -Zunpretty=expanded
Fields
crates: Vec<String>The names of crates to parse with rustc -Zunpretty=expanded
all_features: boolWhether to enable all the features when expanding.
default_features: boolWhether to use the default feature set when expanding.
features: Option<Vec<String>>List of features to use when expanding. Combines with default_features like in
Cargo.toml.
profile: ProfileControls whether or not to pass --release when expanding.